#!/bin/bash

#
# install-symlinks.sh
#
# Script for installing symlinks to these rc files into your home directory.
# It's assumed that your home directory is the directory immediately above this
# one.
#
# Colin McCabe
#

die() {
	echo "$@"
	exit 1
}

if [ -f ../.bashrc ]; then
    if [ -L ../.bashrc ]; then
        :
    else
        echo "moving old .bashrc to .bashrc-old"
        mv -f ../.bashrc ../.bashrc-old
    fi
fi

copy_ssh_old=0
if [ -d ../.ssh ]; then
    if [ -L ../.ssh ]; then
        :
    else
        echo "moving old .ssh to .ssh-old"
        mv -f ../.ssh ../.ssh-old
        copy_ssh_old=1
    fi
fi

BASEDIR=`pwd`
for file in ${BASEDIR}/.[^.]*; do
	# get base file name, like ".gitconfig"
	basefile=`basename ${file}`

	# get relative file name, like "cmccabe-etc/.gitconfig"
	relfile=`echo ${file} | sed 's_.*/\([^/]*/[^/]*\)$_\1_'`

	# skip files which we don't want to link
	[ "${basefile}" == ".git" ] && continue
	[ "${basefile}" == ".gitignore" ] && continue

	pushd .. > /dev/null
	if [ -L ${basefile} ]; then
		# Someone already created this link. Pass over it in silence
		:
	elif [ ! -a ${basefile} ]; then
		# Create the link
		ln -s ${relfile} || die "failed to link ${relfile}"
		echo "created ${relfile}..."
	elif [ -f ${basefile} ]; then
		echo "${basefile} already exists as a regular file"
	else
		echo "${basefile} already exists"
	fi
	popd > /dev/null
done

if [ $copy_ssh_old -eq 1 ]; then
    echo "copying files from .ssh-old to .ssh"
    cp -f ../.ssh-old/* ../.ssh
    echo "chmod 600 ../.ssh/config"
    chmod 600 ../.ssh/*
fi
